ENTRY( _start )

/* Configure heap and stack space reserved for application.
 * Too low may cause standard library failed,
 * too high may cause SDRAM overflow.
 * Collision may occur with heap when stack gets too deep.
 */
__stack_size = 32768;
__heap_size  = 32768;

MEMORY
{
    SRAM    (xrw) : ORIGIN = 0x00020000, LENGTH = 8k
    SDRAM   (xrw) : ORIGIN = 0x4f800000, LENGTH = 8M
}

SECTIONS
{
    .resource_table :
    {
        . = ALIGN(8);
        KEEP(*(SORT_NONE(.resource_table)))
        . = ALIGN(8);
    } >SDRAM

    .init :
    {
        . = ALIGN(8);
        KEEP(*(SORT_NONE(.init)))
        . = ALIGN(8);
    } >SDRAM

    .vectors :
    {
        . = ALIGN(8);
        KEEP(*(SORT_NONE(.vectors)))
        . = ALIGN(8);
    } >SDRAM

    .text :
    {
        . = ALIGN(8);
        _stext = .;

        *(.text)
        *(.text.*)
        *(.gnu.linkonce.t.*)
        *(.rodata)
        *(.rodata*)
        *(.gnu.linkonce.r.*)

        . = ALIGN(8);
        _etext = .;
    } >SDRAM

    .preinit_array  :
    {
        PROVIDE_HIDDEN (__preinit_array_start = .);
        KEEP (*(.preinit_array))
        PROVIDE_HIDDEN (__preinit_array_end = .);
    } >SDRAM

    .init_array :
    {
        PROVIDE_HIDDEN (__init_array_start = .);
        KEEP (*(SORT_BY_INIT_PRIORITY(.init_array.*) SORT_BY_INIT_PRIORITY(.ctors.*)))
        KEEP (*(.init_array EXCLUDE_FILE (*crtbegin.o *crtbegin?.o *crtend.o *crtend?.o ) .ctors))
        PROVIDE_HIDDEN (__init_array_end = .);
    } >SDRAM

    .fini_array :
    {
      PROVIDE_HIDDEN (__fini_array_start = .);
      KEEP (*(SORT_BY_INIT_PRIORITY(.fini_array.*) SORT_BY_INIT_PRIORITY(.dtors.*)))
      KEEP (*(.fini_array EXCLUDE_FILE (*crtbegin.o *crtbegin?.o *crtend.o *crtend?.o ) .dtors))
      PROVIDE_HIDDEN (__fini_array_end = .);
    } >SDRAM

    .ctors :
    {
        KEEP (*crtbegin.o(.ctors))
        KEEP (*crtbegin?.o(.ctors))
        KEEP (*(EXCLUDE_FILE (*crtend.o *crtend?.o ) .ctors))
        KEEP (*(SORT(.ctors.*)))
        KEEP (*(.ctors))
    } >SDRAM

    .dtors :
    {
        KEEP (*crtbegin.o(.dtors))
        KEEP (*crtbegin?.o(.dtors))
        KEEP (*(EXCLUDE_FILE (*crtend.o *crtend?.o ) .dtors))
        KEEP (*(SORT(.dtors.*)))
        KEEP (*(.dtors))
    } >SDRAM

    .data :
    {
        . = ALIGN(8);
        _sdata = .;

        *(.data .data.*)
        *(.gnu.linkonce.d.*)
        *(.sdata .sdata.*)
        *(.srodata .srodata.*)
        *(.gnu.linkonce.s.*)

        . = ALIGN(8);
        _edata = .;
    } >SDRAM

    . = ALIGN(16);
    PROVIDE( __global_pointer$ = . );

    .bss :
    {
        . = ALIGN(8);
        _sbss = .;

        *(.sbss)
        *(.sbss.*)
        *(.gnu.linkonce.sb.*)
        *(.bss)
        *(.bss.*)
        *(.gnu.linkonce.b.*)
        *(COMMON)

        . = ALIGN(8);
        _ebss = .;
    } >SDRAM

    .heap_stack :
    {
        . = ALIGN(16);
        _end = .;
        PROVIDE(end = . );

        . = . + __heap_size;
        . = ALIGN(16);
        PROVIDE(_heap_end = .);

        . = . + __stack_size;
        . = ALIGN(16);
    } >SDRAM

    /* Place initial SP to the end of SDRAM */
    __stack_top = ORIGIN(SDRAM) + LENGTH(SDRAM);
    __freertos_irq_stack_top = __stack_top;
}
